---
title: <span class="badge object-type-scalar"></span> CubicMetersPerSecond
---
# <span class="badge object-type-scalar"></span> CubicMetersPerSecond

Flow: Cubic meters/sec (cms)

## Definition

```python
# Flow: Cubic meters/sec (cms)
CubicMetersPerSecond: typing.Literal["flowcms"] = "flowcms"
```
